@@ -217,6 +217,8 @@ gst_ffmpegdemux_base_init (GstFFMpegDemuxClass * klass)
   gst_element_class_add_pad_template (element_class, audiosrctempl);
   gst_element_class_add_pad_template (element_class, sinktempl);
 
+  gst_caps_unref (sinkcaps);
+
   klass->in_plugin = in_plugin;
   klass->videosrctempl = videosrctempl;
   klass->audiosrctempl = audiosrctempl;
@@ -1089,7 +1091,7 @@ gst_ffmpeg_metadata_to_tag_list (AVDictionary * metadata)
      * header, without handling any variants. */
     ADD_TAG_MAPPING (tmp, "album", GST_TAG_ALBUM);
     ADD_TAG_MAPPING (tmp, "album_artist", GST_TAG_ALBUM_ARTIST);
-    ADD_TAG_MAPPING (tmp, "artist", GST_TAG_ALBUM_ARTIST);
+    ADD_TAG_MAPPING (tmp, "artist", GST_TAG_ARTIST);
     ADD_TAG_MAPPING (tmp, "comment", GST_TAG_COMMENT);
     ADD_TAG_MAPPING (tmp, "composer", GST_TAG_COMPOSER);
     ADD_TAG_MAPPING (tmp, "copyright", GST_TAG_COPYRIGHT);
@@ -1567,9 +1569,7 @@ pause:
         gst_ffmpegdemux_push_event (demux, gst_event_new_eos ());
       }
     } else if (ret == GST_FLOW_NOT_LINKED || ret < GST_FLOW_EOS) {
-      GST_ELEMENT_ERROR (demux, STREAM, FAILED,
-          ("Internal data stream error."),
-          ("streaming stopped, reason %s", gst_flow_get_name (ret)));
+      GST_ELEMENT_FLOW_ERROR (demux, ret);
       gst_ffmpegdemux_push_event (demux, gst_event_new_eos ());
     }
     return;
@@ -2030,8 +2030,9 @@ gst_ffmpegdemux_register (GstPlugin * plugin)
         !strcmp (in_plugin->name, "swf") ||
         !strcmp (in_plugin->name, "voc") ||
         !strcmp (in_plugin->name, "pva") ||
-        !strcmp (in_plugin->name, "gif") || !strcmp (in_plugin->name, "vc1test")
-        )
+        !strcmp (in_plugin->name, "gif") ||
+        !strcmp (in_plugin->name, "vc1test") ||
+        !strcmp (in_plugin->name, "ivf"))
       register_typefind_func = FALSE;
 
     /* Set the rank of demuxers known to work to MARGINAL.
@@ -2068,7 +2069,7 @@ gst_ffmpegdemux_register (GstPlugin * plugin)
         !strcmp (in_plugin->name, "yuv4mpegpipe") ||
         !strcmp (in_plugin->name, "pva") ||
         !strcmp (in_plugin->name, "mpc") ||
-        !strcmp (in_plugin->name, "mpc8") || !strcmp (in_plugin->name, "gif"))
+        !strcmp (in_plugin->name, "mpc8") || !strcmp (in_plugin->name, "ivf"))
       rank = GST_RANK_MARGINAL;
     else {
       GST_DEBUG ("ignoring %s", in_plugin->name);
